@@ -51,7 +51,7 @@ class Model:
             self.age = age
 
     then you can use like follow:
-        init_db(person='xxx', password='xxx', database='xxx', host='xxx', ...)  # or dbx.init_db(...) init db first,
+        orm.init(person='xxx', password='xxx', database='xxx', host='xxx', ...)  # or db.init(...) init db first,
         person = Person(name='张三', age=55)
         effect_rowcount = person.persist()
         id = person.inst_save()
@@ -209,12 +209,12 @@ class Model:
         else:
             select_key = cls._get_select_key()
             if not select_key:
+                keq_seq = cls._get_key_seq()
                 try:
-                    select_key = Dialect.get_select_key(keq_seq=cls._get_key_seq(), table=table, key=key)
+                    select_key = Dialect.get_select_key(keq_seq=keq_seq, table=table, key=key)
                 except NotImplementedError:
-                    if Dialect.curr_engine() == db.Engine.POSTGRESQL:
-                        raise DBError(f"Expect 'key_seq' or 'select_key'. you can set it in model class with '__key_seq__' or '__select_key__'.")
-                    raise DBError(f"Expect 'select_key'. you can set it in model class with '__select_key__'.")
+                    raise DBError("Expect 'select_key'. you can set it in model class with '__select_key__'. "
+                                  "You can also set primary key sequence with '__key_seq__' for PostgreSQL.'")
             return db.save_select_key(select_key, table, **kwargs)
 
     @classmethod
@@ -236,13 +236,10 @@ class Model:
         """
         log_support.logger.debug("Exec func 'sqlbatis.orm.Model.%s' \n\t Class: '%s', id: %d, kwargs: %s" % ('update_by_id', cls.__name__, _id, kwargs))
         assert kwargs, 'Must set update kv'
-        key = cls._get_key()
-        where = '%s = ?' % key
-        cols, args = zip(*kwargs.items())
-        sql, update_time_arg = cls._update_sql(where, *cols)
-        if update_time_arg:
-            args = [*args, update_time_arg]
-        return db.do_execute(sql, *args, _id)
+        key, table_name = cls._get_key_and_table()
+        where_kwargs = {key: _id}
+        kwargs = cls._update_time(**kwargs)
+        db.table(table_name).where(**where_kwargs).update(**kwargs)
 
     @classmethod
     def logical_delete_by_id(cls, _id: Union[int, str], update_by: Union[int, str] = None):
@@ -304,8 +301,8 @@ class Model:
         """
         log_support.logger.debug("Exec func 'sqlbatis.orm.Model.%s' \n\t Class: '%s', id: %d" % ('delete_by_id', cls.__name__, _id))
         key, table = cls._get_key_and_table()
-        sql = 'DELETE FROM %s WHERE %s = ?' % (table, key)
-        return db.do_execute(sql, _id)
+        where_kwargs = {key: _id}
+        return db.table(table).where(**where_kwargs).delete()
 
     @classmethod
     def delete_by_ids(cls, ids: Union[Sequence[int], Sequence[str]], batch_size=128):
@@ -334,10 +331,9 @@ class Model:
         rowcount = Person.do_delete_by_ids(id=[1,2])
         return: Effect rowcount
         """
-        ids_size = len(ids)
         key, table = cls._get_key_and_table()
-        sql = 'DELETE FROM {} WHERE {} in ({})'.format(table, key, ','.join(['?' for _ in range(ids_size)]))
-        return db.do_execute(sql, *ids)
+        where_kwargs = {'{}__in'.format(key): ids}
+        return db.table(table).where(**where_kwargs).delete()
 
     @classmethod
     def batch_insert(cls, *args):
@@ -372,7 +368,13 @@ class Model:
     def exists(cls, **kwargs):
         log_support.orm_count_log('exists', cls.__name__, **kwargs)
         table = cls.get_table()
-        return db.table(table).where( **kwargs).exists()
+        return db.table(table).where(**kwargs).exists()
+
+    @classmethod
+    def exists_by_id(cls, _id: Union[int, str]):
+        key = cls._get_key()
+        kwargs = {key: _id}
+        return cls.exists(**kwargs)
 
     @classmethod
     def find(cls, *fields, **kwargs):
@@ -450,9 +452,8 @@ class Model:
         """
         log_support.orm_find_by_id_log('query_by_id', cls.__name__, _id, *fields)
         key, table = cls._get_key_and_table()
-        where = 'WHERE {} = ?'.format(key)
-        sql = orm_support.get_table_select_sql(table, where, LIMIT_1, *fields)
-        return db.do_query_one(sql, _id, LIMIT_1)
+        kwargs = {key: _id}
+        return db.table(table).columns(*fields).where(**kwargs).query_one()
 
     @classmethod
     def query_by_ids(cls, ids: Union[Sequence[int], Sequence[str]], *fields):
@@ -463,13 +464,11 @@ class Model:
         :param fields: Default select all fields if not set
         """
         log_support.orm_find_by_ids_log('query_by_ids', cls.__name__, ids, *fields)
-        ids_size = len(ids)
-        assert ids_size > 0, 'ids must not be empty.'
+        assert len(ids) > 0, 'ids must not be empty.'
 
         key, table = cls._get_key_and_table()
-        where = 'WHERE {} in ({})'.format(key, ','.join(['?' for _ in range(ids_size)]))
-        sql = orm_support.get_table_select_sql(table, where, ids_size, *fields)
-        return db.do_query(sql, *ids, ids_size)
+        kwargs = {'{}__in'.format(key): ids}
+        return db.table(table).columns(*fields).where(**kwargs).query()
 
     @classmethod
     def select(cls, *fields, **kwargs):
@@ -503,9 +502,8 @@ class Model:
         """
         log_support.orm_find_by_id_log('select_by_id', cls.__name__, _id, *fields)
         key, table = cls._get_key_and_table()
-        where = 'WHERE {} = ?'.format(key)
-        sql = orm_support.get_table_select_sql(table, where, LIMIT_1, *fields)
-        return db.do_select_one(sql, _id, LIMIT_1)
+        kwargs = {key: _id}
+        return db.table(table).columns(*fields).where(**kwargs).select_one()
 
     @classmethod
     def select_by_ids(cls, ids: Union[Sequence[int], Sequence[str]], *fields):
@@ -516,13 +514,11 @@ class Model:
         :param fields: Default select all fields if not set
         """
         log_support.orm_find_by_ids_log('select_by_ids', cls.__name__, ids, *fields)
-        ids_size = len(ids)
-        assert ids_size > 0, 'ids must not be empty.'
+        assert len(ids) > 0, 'ids must not be empty.'
 
         key, table = cls._get_key_and_table()
-        where = 'WHERE {} in ({})'.format(key, ','.join(['?' for _ in range(ids_size)]))
-        sql = orm_support.get_table_select_sql(table, where, ids_size, *fields)
-        return db.do_select(sql, *ids, ids_size)
+        kwargs = {'{}__in'.format(key): ids}
+        return db.table(table).columns(*fields).where(**kwargs).select()
 
     @classmethod
     def find_page(cls, page_num=1, page_size=10, *fields, **kwargs):
@@ -572,8 +568,8 @@ class Model:
         return orm_support.WhereExec(cls, **kwargs)
 
     @classmethod
-    def page(cls, page_num=1, page_size=10) -> orm_support.OrmPage:
-        return cls.where().page(page_num, page_size)
+    def page(cls, page_num=1, page_size=10) -> orm_support.PageExec:
+        return orm_support.PageExec(cls, page_num, page_size)
 
     @classmethod
     def to_obj(cls, **kwargs):
@@ -695,16 +691,24 @@ class Model:
         assert hasattr(cls, DEL_FLAG), "%s not set attribute '%s'" % (cls.__name__, DEL_FLAG)
         return cls.__del_flag__
 
+    @classmethod
+    def _update_time(cls, **kwargs):
+        update_time_field = cls._get_update_time_field()
+        if update_time_field is not None and update_time_field not in kwargs:
+            kwargs[update_time_field] = datetime.now()
+        return kwargs
+
     @classmethod
     def _update_sql(cls, where, *update_fields):
         update_time_arg = None
         table = cls.get_table()
+        table = Dialect.get_dialect_str(table)
         update_time_field = cls._get_update_time_field()
         if update_time_field is not None and update_time_field not in update_fields:
             update_fields = [*update_fields, update_time_field]
             update_time_arg = datetime.now()
 
-        update_fields = ', '.join(['{} = ?'.format(col) for col in update_fields])
+        update_fields = ', '.join(['{} = ?'.format(Dialect.get_dialect_str(col)) for col in update_fields])
         return 'UPDATE {} SET {} WHERE {}'.format(table, update_fields, where), update_time_arg
 
     @classmethod
